Ameck Copilot - AI Coding Assistant

## Welcome to Ameck Copilot

I'm your AI coding assistant powered by FREE models via Groq. I can help you with:

Write Code
Explain Code
Debug Issues
Review Code

## Code Analysis

Paste your code below and select an operation to analyze it.

Analysis results will appear here

## Code Generation

Describe what you want to build and I'll generate the code for you.

Description
Language
Framework (optional)

Generated code will appear here

Thinking...